aboutsummaryrefslogtreecommitdiffstats
path: root/src/channels.cpp
diff options
context:
space:
mode:
authorGravatar brain2007-02-19 19:57:41 +0000
committerGravatar brain2007-02-19 19:57:41 +0000
commitc1f88cfa9c653c0df9574edb6995a7385543be83 (patch)
treef7a63f36b05e72de2a76913b93e61d990eebfd84 /src/channels.cpp
parentToo many small tweaks to list. Most notably tidy up info, note that /trace is... (diff)
Addition of feature request outlined in bug #195, suggested by Bricker
git-svn-id: http://svn.inspircd.org/repository/trunk/inspircd@6602 e03df62e-2008-0410-955e-edbf42e46eb7
Diffstat (limited to 'src/channels.cpp')
-rw-r--r--src/channels.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/channels.cpp b/src/channels.cpp
index 5383f4aba..366169dd6 100644
--- a/src/channels.cpp
+++ b/src/channels.cpp
@@ -296,22 +296,22 @@ chanrec* chanrec::JoinUser(InspIRCd* Instance, userrec *user, const char* cn, bo
}
/* NOTE: If the user is an oper here, we can extend their user->chans by up to
* OPERMAXCHANS. For remote users which are not bound by the channel limits,
* we can extend infinitely. Otherwise, nope, youre restricted to MAXCHANS.
*/
- if (!IS_LOCAL(user) || override == true) /* was a check on fd < 0 */
+ if (!IS_LOCAL(user) || override == true)
{
return chanrec::ForceChan(Instance, Ptr, user, privs);
}
else if (*user->oper)
{
- /* Oper allows extension up to the OPERMAXCHANS value */
- if (user->chans.size() < OPERMAXCHANS)
+ /* Oper allows extension up to the OperMaxchans value */
+ if (user->chans.size() < Instance->Config->OperMaxChans)
{
return chanrec::ForceChan(Instance, Ptr, user, privs);
}
}
- else if (user->chans.size() < MAXCHANS)
+ else if (user->chans.size() < Instance->Config->MaxChans)
{
return chanrec::ForceChan(Instance, Ptr, user, privs);
}
@@ -296,22 +296,22 @@ chanrec* chanrec::JoinUser(InspIRCd* Instance, userrec *user, const char* cn, bo
}
/* NOTE: If the user is an oper here, we can extend their user->chans by up to
- * OPERMAXCHANS. For remote users which are not bound by the channel limits,
- * we can extend infinitely. Otherwise, nope, youre restricted to MAXCHANS.
+ * OperMaxchans. For remote users which are not bound by the channel limits,
+ * we can extend infinitely. Otherwise, nope, youre restricted to MaxChans.
*/